@@ -3,10 +3,8 @@ from os.path import join
 import struct
 import gtk, gtk.gdk, gtk.glade, gobject, gconf
 import deskbar, deskbar.Utils
-from deskbar.updater.NewStuffUpdater import NewStuffUpdater
-from deskbar.ui.ModuleListView import ModuleListView, WebModuleListView
-from deskbar.ModuleList import WebModuleList
-from deskbar import CUEMIAC_UI_NAME, ENTRIAC_UI_NAME
+from deskbar.ui.ModuleListView import ModuleListView
+from deskbar import CUEMIAC_UI_NAME, ENTRIAC_UI_NAME, WINDOW_UI_NAME
 
 MAXINT = 2 ** ((8 * struct.calcsize('i')) - 1) - 1
 
@@ -135,14 +133,11 @@ class AccelEntry( gobject.GObject ):
 class DeskbarPreferencesUI:
 	def __init__(self, applet, module_loader, module_list):
 		self.module_list = module_list
-		self.web_module_list = WebModuleList()
 		self.module_loader = module_loader
 		self.glade = gtk.glade.XML(join(deskbar.SHARED_DATA_DIR, "prefs-dialog.glade"))
 		
 		self.dialog = self.glade.get_widget("preferences")
 		
-		self.newstuff = NewStuffUpdater(self.dialog, module_loader, module_list, self.web_module_list)
-		
 		# Retreive current values
 		self.width = deskbar.GCONF_CLIENT.get_int(applet.prefs.GCONF_WIDTH)
 		self.expand = deskbar.GCONF_CLIENT.get_bool(applet.prefs.GCONF_EXPAND)
@@ -195,21 +190,10 @@ class DeskbarPreferencesUI:
 		self.cuemiac_ui_radio.connect ("toggled", self.on_ui_changed, applet)
 		self.ui_change_id = deskbar.GCONF_CLIENT.notify_add(applet.prefs.GCONF_UI_NAME, lambda x, y, z, a: self.on_config_ui(z.value))
 		
-		container = self.glade.get_widget("newhandlers")
-		self.webmoduleview = WebModuleListView(self.web_module_list)
-		self.webmoduleview.get_selection().connect("changed", self.on_webmodule_selected)
-		self.web_module_list.connect('row-changed', lambda list, path, iter: self.on_webmodule_selected(self.webmoduleview.get_selection()))
-		
-		container.add(self.webmoduleview)
-		
-		self.install = self.glade.get_widget("install")
-		self.check = self.glade.get_widget("check")
-		self.update = self.glade.get_widget("update")
-		
-		self.check.connect('clicked', self.on_check_handlers)
-		self.update.connect('clicked', self.on_update_handler)
-		self.update.set_sensitive(False)
-		self.install.connect('clicked', self.on_install_handler)
+		self.use_selection = deskbar.GCONF_CLIENT.get_bool(applet.prefs.GCONF_USE_SELECTION)
+		self.use_selection_box = self.glade.get_widget("use_selection")
+		self.use_selection_box.connect('toggled', self.on_use_selection_toggled, applet)
+		self.use_selection_id = deskbar.GCONF_CLIENT.notify_add(applet.prefs.GCONF_USE_SELECTION, lambda x, y, z, a: self.on_config_use_selection(z.value))
 		
 		self.sync_ui()
 		
@@ -220,7 +204,6 @@ class DeskbarPreferencesUI:
 	
 	def on_dialog_response(self, dialog, response):	
 		self.dialog.destroy()
-		self.newstuff.close()
 		
 		deskbar.GCONF_CLIENT.notify_remove(self.width_notify_id)
 		deskbar.GCONF_CLIENT.notify_remove(self.expand_notify_id)
@@ -250,6 +233,12 @@ class DeskbarPreferencesUI:
 		elif self.ui_name == CUEMIAC_UI_NAME:
 			self.cuemiac_ui_radio.set_active (True)
 			self.set_width_settings_sensitive(False)
+		elif self.ui_name == WINDOW_UI_NAME:
+			self.cuemiac_ui_radio.set_active (True)
+			self.set_ui_settings_sensitive(False)
+			self.set_width_settings_sensitive(False)
+		
+		self.use_selection_box.set_active(self.use_selection)
 			
 	def set_width_settings_sensitive(self, sensitive):
 		if sensitive and not self.expand:
@@ -261,6 +250,11 @@ class DeskbarPreferencesUI:
 			
 		self.use_all_width_radio.set_sensitive(sensitive)
 		self.fixed_width_radio.set_sensitive(sensitive)
+
+	def set_ui_settings_sensitive(self, sensitive):
+		self.cuemiac_ui_radio.set_sensitive(sensitive)
+		self.completion_ui_radio.set_sensitive(sensitive)
+
 		
 	def on_config_width(self, value):
 		if value != None and value.type == gconf.VALUE_INT:
@@ -281,8 +275,16 @@ class DeskbarPreferencesUI:
 		if value != None and value.type == gconf.VALUE_STRING:
 			self.ui_name = value.get_string ()
 			self.sync_ui()
+	
+	def on_config_use_selection(self, value):
+		if value != None and value.type == gconf.VALUE_BOOL:
+			self.use_selection = value.get_bool()
+			self.sync_ui()
 			
 	def on_ui_changed (self, sender, applet):
+		if self.ui_name == WINDOW_UI_NAME:
+			# You cannot change to or from window ui
+			return
 		if self.completion_ui_radio.get_active ():
 			deskbar.GCONF_CLIENT.set_string(applet.prefs.GCONF_UI_NAME, ENTRIAC_UI_NAME)
 		elif self.cuemiac_ui_radio.get_active ():
@@ -299,6 +301,9 @@ class DeskbarPreferencesUI:
 				deskbar.GCONF_CLIENT.set_string(applet.prefs.GCONF_KEYBINDING, accel_name)
 		return False
 
+	def on_use_selection_toggled(self, toggle, applet):
+		deskbar.GCONF_CLIENT.set_bool(applet.prefs.GCONF_USE_SELECTION, toggle.get_active())
+		
 	def on_more_button_clicked(self, button):
 		if self.more_button_callback != None:
 			self.more_button_callback(self.dialog)
@@ -308,14 +313,7 @@ class DeskbarPreferencesUI:
 		if module_context != None:
 			self.check_requirements(module_context)
 			gobject.timeout_add(1000, self.poll_requirements, module_context)
-			
-		# Check if we can update
-		self.update.set_sensitive(module_context != None and module_context.update_infos[0])				
 	
-	def on_webmodule_selected(self, selection):
-		module_context = self.webmoduleview.get_selected_module_context()
-		self.install.set_sensitive(module_context != None and not module_context.installing)
-		
 	def poll_requirements(self, module_context):
 		try:
 			if module_context != self.moduleview.get_selected_module_context():
@@ -350,6 +348,7 @@ class DeskbarPreferencesUI:
 		self.info_area.remove(self.info_area.get_children()[0])
 		if message == None:
 			self.info_area.add(self.default_info)
+			self.more_button.set_sensitive(False)
 		else:
 			self.other_info_label.set_text(message)
 			self.info_area.add(self.other_info)
@@ -363,23 +362,5 @@ class DeskbarPreferencesUI:
 		else:
 			loader.initialize_module_async (context)
 			
-	def on_check_handlers(self, button):
-		#Update all handlers
-		self.newstuff.check_all()
-		
-	def on_update_handler(self, button):
-		module_context = self.moduleview.get_selected_module_context()
-		if module_context != None:
-			# Trigger module update
-			self.newstuff.update(module_context)
-			button.set_sensitive(False)
-		
-	def on_install_handler(self, button):
-		# Install the selected new handler
-		module_context = self.webmoduleview.get_selected_module_context()
-		if module_context != None:
-			self.newstuff.install(module_context)
-			button.set_sensitive(False)
-			
 def show_preferences(applet, loader, model):
 	DeskbarPreferencesUI(applet, loader, model).show_run_hide()
